Script: *new-dir.ps1*
========================

This PowerShell script creates an empty new directory in the filesystem.

Parameters
----------
```powershell
PS> ./new-dir.ps1 [[-path] <String>] [<CommonParameters>]

-path <String>
    Specifies the path and filename of the new directory
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./new-dir.ps1 MyCollection
✔️ New 📂C:\Temp\MyCollection created.

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Creates a new directory
.DESCRIPTION
	This PowerShell script creates an empty new directory in the filesystem.
.PARAMETER path
	Specifies the path and filename of the new directory
.EXAMPLE
	PS> ./new-dir.ps1 MyCollection
	✔️ New 📂C:\Temp\MyCollection created.
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$path = "")

try {
	if ($path -eq "") { $path = Read-Host "Enter the filename (and path) of the new directory" }

	if (Test-Path $path) { throw "Directory at $path already exists" }

	$null =	(New-Item -itemType directory -path $path)

	$path = Resolve-Path $path
	"✔️ New 📂$path created."
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of new-dir.ps1 as of 05/19/2024 10:25:23)*
