Script: *write-quote.ps1*
========================

This PowerShell script selects a random quote from .../data/quotes.csv and writes it to the console.

Parameters
----------
```powershell
PS> ./write-quote.ps1 [<CommonParameters>]

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./write-quote.ps1
“ We must become the change we want to see. „
                           - Mahatma Gandhi

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Writes a random quote
.DESCRIPTION
	This PowerShell script selects a random quote from .../data/quotes.csv and writes it to the console.
.EXAMPLE
	PS> ./write-quote.ps1
	“ We must become the change we want to see. „
	                           - Mahatma Gandhi
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

try {
	$table = Import-CSV "$PSScriptRoot/../data/quotes.csv"

	$randomNumberGenerator = New-Object System.Random
	$row = [int]$randomNumberGenerator.next(0, $table.Count - 1)
	$quote = $table[$row].QUOTE
	$author = $table[$row].AUTHOR
	$spaces = "                                                                                                                             "
	$spaces = $spaces.Substring(0, $quote.Length - $author.Length)

	Write-Host "`n"'“'"$quote"'„'"" -foregroundColor Green
	Write-Host "$spaces- $author" -foregroundColor Blue
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of write-quote.ps1 as of 05/19/2024 10:25:27)*
